# ecfrow.py
# Copyright 2008 Roger Marsh
# Licence: See LICENCE (BSD licence)

"""Create widgets that display ECF club and player details.
"""

import tkinter

from solentware_grid.gui.datarow import DataRow
from solentware_grid.gui.datarow import GRID_COLUMNCONFIGURE, GRID_CONFIGURE
from solentware_grid.gui.datarow import WIDGET_CONFIGURE, WIDGET, ROW

from ..core import ecfrecord


class ECFrefDBrowECFClub(ecfrecord.ECFrefDBrecordECFclub, DataRow):

    """Display an ECF Club record.

    Note that this is the subset of fields copied from master file.

    """
    header_specification = [
        {WIDGET: tkinter.Label,
         WIDGET_CONFIGURE: dict(text='Club code', anchor=tkinter.CENTER),
         GRID_CONFIGURE: dict(column=0, sticky=tkinter.EW),
         GRID_COLUMNCONFIGURE: dict(weight=0, uniform='ccode'),
         ROW: 0,
         },
        {WIDGET: tkinter.Label,
         WIDGET_CONFIGURE: dict(text='Name', anchor=tkinter.W),
         GRID_CONFIGURE: dict(column=1, sticky=tkinter.EW),
         GRID_COLUMNCONFIGURE: dict(weight=1, uniform='cname'),
         ROW: 0,
         },
        ]

    def __init__(self, database=None):
        """Extend, link ECF club record from master file to database."""
        super(ECFrefDBrowECFClub, self).__init__()
        self.set_database(database)
        self.row_specification = [
            {WIDGET: tkinter.Label,
             WIDGET_CONFIGURE: dict(anchor=tkinter.CENTER),
             GRID_CONFIGURE: dict(column=0, sticky=tkinter.EW),
             ROW: 0,
             },
            {WIDGET: tkinter.Label,
             WIDGET_CONFIGURE: dict(anchor=tkinter.W),
             GRID_CONFIGURE: dict(column=1, sticky=tkinter.EW),
             ROW: 0,
             },
            ]
        
    def grid_row(self, **kargs):
        """Return super(ECFrefDBrowECFClub,).grid_row(textitems=(...), **kargs).

        Create textitems argument for ECFrefDBrowECFClub instance.

        """
        return super(ECFrefDBrowECFClub, self).grid_row(
            textitems=(
                self.value.ECFcode if self.value.ECFactive else '',
                self.value.ECFname if self.value.ECFactive else ''),
            **kargs)


class ECFrefDBrowECFPlayer(ecfrecord.ECFrefDBrecordECFplayer, DataRow):

    """Display an ECF player record.

    Note that this is the subset of fields copied from master file.

    """
    header_specification = [
        {WIDGET: tkinter.Label,
         WIDGET_CONFIGURE: dict(text='Grading code', anchor=tkinter.CENTER),
         GRID_CONFIGURE: dict(column=0, sticky=tkinter.EW),
         GRID_COLUMNCONFIGURE: dict(weight=0, uniform='pcode'),
         ROW: 0,
         },
        {WIDGET: tkinter.Label,
         WIDGET_CONFIGURE: dict(text='Merge', anchor=tkinter.CENTER),
         GRID_CONFIGURE: dict(column=1, sticky=tkinter.EW),
         GRID_COLUMNCONFIGURE: dict(weight=0, uniform='pmerge'),
         ROW: 0,
         },
        {WIDGET: tkinter.Label,
         WIDGET_CONFIGURE: dict(text='Name (ECF)', anchor=tkinter.W),
         GRID_CONFIGURE: dict(column=2, sticky=tkinter.EW),
         GRID_COLUMNCONFIGURE: dict(weight=1, uniform='pname'),
         ROW: 0,
         },
        {WIDGET: tkinter.Label,
         WIDGET_CONFIGURE: dict(text='Clubs', anchor=tkinter.W),
         GRID_CONFIGURE: dict(column=3, sticky=tkinter.EW),
         GRID_COLUMNCONFIGURE: dict(weight=1, uniform='pclubs'),
         ROW: 0,
         },
        ]

    def __init__(self, database=None):
        """Extend, link ECF player record from master file to database."""
        super(ECFrefDBrowECFPlayer, self).__init__()
        self.set_database(database)
        self.row_specification = [
            {WIDGET: tkinter.Label,
             WIDGET_CONFIGURE: dict(anchor=tkinter.CENTER),
             GRID_CONFIGURE: dict(column=0, sticky=tkinter.EW),
             ROW: 0,
             },
            {WIDGET: tkinter.Label,
             WIDGET_CONFIGURE: dict(anchor=tkinter.W),
             GRID_CONFIGURE: dict(column=1, sticky=tkinter.EW),
             ROW: 0,
             },
            {WIDGET: tkinter.Label,
             WIDGET_CONFIGURE: dict(anchor=tkinter.W),
             GRID_CONFIGURE: dict(column=2, sticky=tkinter.EW),
             ROW: 0,
             },
            {WIDGET: tkinter.Label,
             WIDGET_CONFIGURE: dict(anchor=tkinter.W),
             GRID_CONFIGURE: dict(column=3, sticky=tkinter.EW),
             ROW: 0,
             },
            ]
        
    def grid_row(self, **kargs):
        """Return super(ECFrefDBrowECFPlayer,).grid_row(textitems=(.), **kargs).

        Create textitems argument for ECFrefDBrowECFPlayer instance.

        """
        if self.value.ECFmerge:
            merged_into = self.value.ECFmerge
        else:
            merged_into = ''
        return super(ECFrefDBrowECFPlayer, self).grid_row(
            textitems=(
                self.value.ECFcode if self.value.ECFactive else '',
                merged_into,
                self.value.ECFname if self.value.ECFactive else '',
                '\t\t'.join(ecfrecord.get_ecf_clubs_for_player(
                    self.database,
                    self.value.ECFclubcodes))),
            **kargs)
